Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(666)

Unified Diff: runtime/vm/raw_object.h

Issue 868103002: VM: Use PC offset instead of absolute PC in exception handler info. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object_test.cc ('k') | runtime/vm/stack_frame.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object.h
===================================================================
--- runtime/vm/raw_object.h (revision 43131)
+++ runtime/vm/raw_object.h (working copy)
@@ -1023,9 +1023,10 @@
struct PcDescriptorRec {
uword pc_offset() const { return pc_offset_; }
void set_pc_offset(uword value) {
-#if defined(TARGET_ARCH_X64) || defined(TARGET_ARCH_ARM64)
- ASSERT(value <= static_cast<uword>(kMaxUint32));
-#endif
+ // Some C compilers warn about the comparison always being true when using
+ // <= due to limited range of data type.
+ ASSERT((value == static_cast<uword>(kMaxUint32)) ||
+ (value < static_cast<uword>(kMaxUint32)));
pc_offset_ = value;
}
@@ -1200,7 +1201,7 @@
// The index into the ExceptionHandlers table corresponds to
// the try_index of the handler.
struct HandlerInfo {
- intptr_t handler_pc; // PC value of handler.
+ uint32_t handler_pc_offset; // PC offset value of handler.
int16_t outer_try_index; // Try block index of enclosing try block.
int8_t needs_stacktrace; // True if a stacktrace is needed.
int8_t has_catch_all; // Catches all exceptions.
« no previous file with comments | « runtime/vm/object_test.cc ('k') | runtime/vm/stack_frame.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698